Class: Google::Api::BatchingSettingsProto

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/client.rb

Overview

BatchingSettingsProto specifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request. At least one threshold must be positive nonzero.

Instance Attribute Summary collapse

Instance Attribute Details

#delay_threshold::Google::Protobuf::Duration

Returns The duration after which a batch should be sent, starting from the addition of the first message to that batch.

Returns:

  • (::Google::Protobuf::Duration)

    The duration after which a batch should be sent, starting from the addition of the first message to that batch.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#element_count_limit::Integer

Returns The maximum number of elements collected in a batch that could be accepted by server.

Returns:

  • (::Integer)

    The maximum number of elements collected in a batch that could be accepted by server.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#element_count_threshold::Integer

Returns The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.

Returns:

  • (::Integer)

    The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flow_control_byte_limit::Integer

Returns The maximum size of data allowed by flow control.

Returns:

  • (::Integer)

    The maximum size of data allowed by flow control.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flow_control_element_limit::Integer

Returns The maximum number of elements allowed by flow control.

Returns:

  • (::Integer)

    The maximum number of elements allowed by flow control.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flow_control_limit_exceeded_behavior::Google::Api::FlowControlLimitExceededBehaviorProto

Returns The behavior to take when the flow control limit is exceeded.

Returns:



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_byte_limit::Integer

Returns The maximum size of the request that could be accepted by server.

Returns:

  • (::Integer)

    The maximum size of the request that could be accepted by server.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_byte_threshold::Integer

Returns The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.

Returns:

  • (::Integer)

    The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.



509
510
511
512
# File 'proto_docs/google/api/client.rb', line 509

class BatchingSettingsProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end