Class: Google::Cloud::WebRisk::V1::WebRiskService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::WebRisk::V1::WebRiskService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/web_risk/v1/web_risk_service/client.rb
Overview
Client for the WebRiskService service.
Web Risk API defines an interface to detect malicious URLs on your website and in client applications.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::WebRisk::V1::WebRiskService::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the WebRiskService Client class.
Instance Method Summary collapse
-
#compute_threat_list_diff(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::WebRisk::V1::ComputeThreatListDiffResponse
Gets the most recent threat list diffs.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the WebRiskService Client instance.
-
#create_submission(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::WebRisk::V1::Submission
Creates a Submission of a URI suspected of containing phishing content to be reviewed.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new WebRiskService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#search_hashes(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::WebRisk::V1::SearchHashesResponse
Gets the full hashes that match the requested hash prefix.
-
#search_uris(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::WebRisk::V1::SearchUrisResponse
This method is used to check whether a URI is on a given threatList.
-
#submit_uri(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Submits a URI suspected of containing malicious content to be reviewed.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new WebRiskService client object.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 142 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/webrisk/v1/webrisk_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @web_risk_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::WebRisk::V1::WebRiskService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @web_risk_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::WebRisk::V1::WebRiskService::Operations (readonly)
Get the associated client for long-running operations.
205 206 207 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 205 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the WebRiskService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "WebRisk", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.compute_threat_list_diff.timeout = 600.0 default_config.rpcs.compute_threat_list_diff.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.search_uris.timeout = 600.0 default_config.rpcs.search_uris.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.search_hashes.timeout = 600.0 default_config.rpcs.search_hashes.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.create_submission.timeout = 600.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#compute_threat_list_diff(request, options = nil) ⇒ ::Google::Cloud::WebRisk::V1::ComputeThreatListDiffResponse #compute_threat_list_diff(threat_type: nil, version_token: nil, constraints: nil) ⇒ ::Google::Cloud::WebRisk::V1::ComputeThreatListDiffResponse
Gets the most recent threat list diffs. These diffs should be applied to a local database of hashes to keep it up-to-date. If the local database is empty or excessively out-of-date, a complete snapshot of the database will be returned. This Method only updates a single ThreatList at a time. To update multiple ThreatList databases, this method needs to be called once for each list.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 277 def compute_threat_list_diff request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::WebRisk::V1::ComputeThreatListDiffRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.compute_threat_list_diff..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::WebRisk::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.compute_threat_list_diff.timeout, metadata: , retry_policy: @config.rpcs.compute_threat_list_diff.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @web_risk_service_stub.call_rpc :compute_threat_list_diff, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the WebRiskService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
112 113 114 115 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 112 def configure yield @config if block_given? @config end |
#create_submission(request, options = nil) ⇒ ::Google::Cloud::WebRisk::V1::Submission #create_submission(parent: nil, submission: nil) ⇒ ::Google::Cloud::WebRisk::V1::Submission
Creates a Submission of a URI suspected of containing phishing content to be reviewed. If the result verifies the existence of malicious phishing content, the site will be added to the Google's Social Engineering lists in order to protect users that could get exposed to this threat in the future. Only allowlisted projects can use this method during Early Access. Please reach out to Sales or your customer engineer to obtain access.
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 534 def create_submission request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::WebRisk::V1::CreateSubmissionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_submission..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::WebRisk::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_submission.timeout, metadata: , retry_policy: @config.rpcs.create_submission.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @web_risk_service_stub.call_rpc :create_submission, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
212 213 214 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 212 def logger @web_risk_service_stub.logger end |
#search_hashes(request, options = nil) ⇒ ::Google::Cloud::WebRisk::V1::SearchHashesResponse #search_hashes(hash_prefix: nil, threat_types: nil) ⇒ ::Google::Cloud::WebRisk::V1::SearchHashesResponse
Gets the full hashes that match the requested hash prefix. This is used after a hash prefix is looked up in a threatList and there is a match. The client side threatList only holds partial hashes so the client must query this method to determine if there is a full hash match of a threat.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 448 def search_hashes request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::WebRisk::V1::SearchHashesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.search_hashes..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::WebRisk::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.search_hashes.timeout, metadata: , retry_policy: @config.rpcs.search_hashes.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @web_risk_service_stub.call_rpc :search_hashes, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#search_uris(request, options = nil) ⇒ ::Google::Cloud::WebRisk::V1::SearchUrisResponse #search_uris(uri: nil, threat_types: nil) ⇒ ::Google::Cloud::WebRisk::V1::SearchUrisResponse
This method is used to check whether a URI is on a given threatList. Multiple threatLists may be searched in a single query. The response will list all requested threatLists the URI was found to match. If the URI is not found on any of the requested ThreatList an empty response will be returned.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 361 def search_uris request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::WebRisk::V1::SearchUrisRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.search_uris..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::WebRisk::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.search_uris.timeout, metadata: , retry_policy: @config.rpcs.search_uris.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @web_risk_service_stub.call_rpc :search_uris, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#submit_uri(request, options = nil) ⇒ ::Gapic::Operation #submit_uri(parent: nil, submission: nil, threat_info: nil, threat_discovery: nil) ⇒ ::Gapic::Operation
Submits a URI suspected of containing malicious content to be reviewed. Returns a google.longrunning.Operation which, once the review is complete, is updated with its result. You can use the Pub/Sub API to receive notifications for the returned Operation. If the result verifies the existence of malicious content, the site will be added to the Google's Social Engineering lists in order to protect users that could get exposed to this threat in the future. Only allowlisted projects can use this method during Early Access. Please reach out to Sales or your customer engineer to obtain access.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 642 def submit_uri request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::WebRisk::V1::SubmitUriRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.submit_uri..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::WebRisk::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.submit_uri.timeout, metadata: , retry_policy: @config.rpcs.submit_uri.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @web_risk_service_stub.call_rpc :submit_uri, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
122 123 124 |
# File 'lib/google/cloud/web_risk/v1/web_risk_service/client.rb', line 122 def universe_domain @web_risk_service_stub.universe_domain end |