Class: Google::Cloud::WebRisk::V1::ThreatInfo::Confidence
- Inherits:
-
Object
- Object
- Google::Cloud::WebRisk::V1::ThreatInfo::Confidence
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/webrisk/v1/webrisk.rb
Overview
Confidence that a URI is unsafe.
Defined Under Namespace
Modules: ConfidenceLevel
Instance Attribute Summary collapse
-
#level ⇒ ::Google::Cloud::WebRisk::V1::ThreatInfo::Confidence::ConfidenceLevel
Enum representation of confidence.
-
#score ⇒ ::Float
A decimal representation of confidence in the range of 0 to 1 where 0 indicates no confidence and 1 indicates complete confidence.
Instance Attribute Details
#level ⇒ ::Google::Cloud::WebRisk::V1::ThreatInfo::Confidence::ConfidenceLevel
Returns Enum representation of confidence.
Note: The following fields are mutually exclusive: level, score. If a field in that set is populated, all other fields in the set will automatically be cleared.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'proto_docs/google/cloud/webrisk/v1/webrisk.rb', line 332 class Confidence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum representation of confidence. module ConfidenceLevel # Default. CONFIDENCE_LEVEL_UNSPECIFIED = 0 # Less than 60% confidence that the URI is unsafe. LOW = 1 # Between 60% and 80% confidence that the URI is unsafe. MEDIUM = 2 # Greater than 80% confidence that the URI is unsafe. HIGH = 3 end end |
#score ⇒ ::Float
Returns A decimal representation of confidence in the range of 0 to 1 where 0 indicates no confidence and 1 indicates complete confidence.
Note: The following fields are mutually exclusive: score, level. If a field in that set is populated, all other fields in the set will automatically be cleared.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'proto_docs/google/cloud/webrisk/v1/webrisk.rb', line 332 class Confidence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum representation of confidence. module ConfidenceLevel # Default. CONFIDENCE_LEVEL_UNSPECIFIED = 0 # Less than 60% confidence that the URI is unsafe. LOW = 1 # Between 60% and 80% confidence that the URI is unsafe. MEDIUM = 2 # Greater than 80% confidence that the URI is unsafe. HIGH = 3 end end |